;=========================================================================
;                                                                        =
;                          Physics Solver v2.4                           =
;                                                                        =
; Written By:   Morgan Davies (morgazum85@gmail.com)                     =
;               Matt Bennett  (Mbcalcman@Yahoo.com)                      =
;                                                                        =
; Bio:  This program is relatively easy to follow, well except for the   =
;       math routines. Which were optimized and thus are really hard to  =
;       follow. If you have any questions about this code, or need help  =
;       with Ti-86 assembly math, Morgan would be more than happy to     =
;       help you at the E-mail address above. If you borrow please give  =
;       credit. Questions and comments are welcome at both E-mail        =
;       addresses listed above.                                          =
;                                                                        =
;=========================================================================
;                                                 =   Equations List     =
;               Physics Solver v2.4               =                      =
;                     Vectors                     =   1) sin =Opp/Hyp   =
;                                                 =   2) cos =Adj/Hyp   =
;                                                 =   3) tan =Opp/Adj   =
;   Size:   1630 Bytes                            =   4) A+B=C        =
;                                                 =   5) Fv=F(sin )     =
;   Keys:   Left    =   View Equations List 1     =   6) Fh=F(cos )     =
;           Right   =   View Equations List 2     =   7) F||=W(sin )    =
;           1-9     =   Select Equation           =   8) Fper=W(cos )   =
;           F1-F4   =   Select Variable           =   9) A=W(sin )/M    =
;           Exit    =   Exits Program             =                      =
;           Alpha   =   Shuts Off Calculator      =                      =
;                                                 =                      =
;=========================================================================


#include "ti86asm.inc"
#include "Asm86.h"
#include "Rom86.h"

.plugin lite86

_ioprompt   =$c324
_asap_ind   =$d623
_getcode    =$4068

.org _asm_exec_ram 

    nop                             ;no operation so...
    jp Start                        ;relative jump to Start
    .dw 0                           ;type of input
    .dw STR1                        ;print string

STR1:   .db "Physics Solver v2.4",0

Start:
    set trigdeg,(iy+trigflags)      ;turns on degree mode
    call _flushallmenus             ;clears all key codes
    call _runindicoff               ;turn off run indicator
    call Text1                      ;goes to Text1
    ld hl,STR2                      ;loads hl with string
    call _puts                      ;print string
    res 3,(iy+5)                    ;reverts text back to black on white
    ld hl,(256*1)+2                 ;loads coordinates into hl, row 2, col 3
    ld (_curRow),hl                 ;loads _curRow with hl
    ld hl,STR1                      ;loads hl with string
    call _puts                      ;print string
    ld hl,(256*2)+4                 ;loads coordinates into hl
    ld (_curRow),hl                 ;loads _curRow with hl
    ld hl,STR3                      ;loads hl with string
    call Text3                      ;goes to Text3
    call _getkey                    ;waits for a key to be pressed

Equations1:
    call Text10                     ;goes to Text10
    ld hl,(256*2)+1                 ;loads coordinates into hl
    ld (_curRow),hl                 ;loads _curRow with hl
    ld hl,STR5                      ;loads hl with string
    call Text3                      ;goes to Text3
    ld hl,$ff70                     ;loads coordinates into hl
    call Text9                      ;goes to Text9
    jr LoopKey                      ;relative jump to LoopKey

Equations2:
    call Text10                     ;goes to Text10
    ld hl,(256*2)+2                 ;loads coordinates into hl
    ld (_curRow),hl                 ;loads _curRow with hl
    ld hl,STR6                      ;print string
    call Text3                      ;goes to Text3
    ld hl,$ff73                     ;loads coordinates into hl
    call Text9                      ;goes to Text9

LoopKey:
    call _getcode                   ;stores key pressed into a
GetKey:
    cp K_EXIT                       ;compares a with Exit key
    jp z,Exit                       ;if Exit jump to Exit
    cp K_1                          ;compares a with 1 key
    jr z,EQU1                       ;if 1 relative jump to EQU1
    cp K_2                          ;compares a with 2 key
    jp z,EQU2                       ;if 2 jump to EQU2
    cp K_3                          ;compares a with 3 key
    jp z,EQU3                       ;if 3 jump to EQU3
    cp K_4                          ;compares a with 4 key
    jp z,EQU4                       ;if 4 jump to EQU4
    cp K_5                          ;compares a with 5 key
    jp z,EQU5                       ;if 5 jump to EQU5
    cp K_6                          ;compares a with 6 key
    jp z,EQU6                       ;if 6 jump to EQU6
    cp K_7                          ;compares a with 7 key
    jp z,EQU7                       ;if 7 jump to EQU7
    cp K_8                          ;compares a with 8 key
    jp z,EQU8                       ;if 8 jump to EQU8
    cp K_9                          ;compares a with 9 key
    jp z,EQU9                       ;if 9 jump to EQU9
    cp K_LEFT                       ;compares a with 9 key
    jp z,Equations1                 ;if Left jump to Equations1
    cp K_RIGHT                      ;compares a with 9 key
    jr z,Equations2                 ;if Right relative jump to Equations1
    call Text8                      ;goes to Text8
    ld a,c                          ;loads a with c
    cp 1                            ;compares a with 1 key
    jr z,Equation1GetKey            ;if 1 relative jump to Equation1GetKey
    cp 2                            ;compares a with 2 key
    jr z,Equation2GetKey            ;if 2 relative jump to Equation2GetKey
    cp 3                            ;compares a with 3 key
    jp z,Equation3GetKey            ;if 3 jump to Equation3GetKey
    cp 4                            ;compares a with 4 key
    jp z,Equation4GetKey            ;if 4 jump to Equation4GetKey
    cp 5                            ;compares a with 5 key
    jp z,Equation5GetKey            ;if 5 jump to Equation5GetKey
    cp 6                            ;compares a with 6 key
    jp z,Equation6GetKey            ;if 6 jump to Equation6GetKey
    cp 7                            ;compares a with 7 key
    jp z,Equation7GetKey            ;if 7 jump to Equation7GetKey
    cp 8                            ;compares a with 8 key
    jp z,Equation8GetKey            ;if 8 jump to Equation8GetKey
    cp 9                            ;compares a with 9 key
    jp z,Equation9GetKey            ;if 9 jump to Equation9GetKey
    jr LoopKey                      ;relative jump to LoopKey

EQU1:
    call Text1                      ;goes to Text1
    ld hl,STR7                      ;loads hl with string
    call Text2                      ;goes to Text2
    ld hl,STR18                     ;loads hl with string
    call Text3                      ;goes to Text3
    ld hl,$ff76                     ;loads coordinates into hl
    ld (hl),%00000001               ;what to display @ hl

Equation1GetKey:
    call _getcode                   ;stores key pressed into a
    cp K_F1                         ;compares a with F1 key
    jp z,VAR1                       ;if F1 jump to VAR1
    cp K_F2                         ;compares a with F2 key
    jp z,VAR2                       ;if F2 jump to VAR2
    cp K_F3                         ;compares a with F3 key
    jp z,VAR3                       ;if F3 jump to VAR3
    call Text8                      ;goes to Text8
    ld c,1                          ;loads c with 1
    jp GetKey                       ;jump to GetKey

EQU2:
    call Text1                      ;goes to Text1
    ld hl,STR8                      ;loads hl with string
    call Text2                      ;goes to Text2
    ld hl,STR19                     ;loads hl with string
    call Text3                      ;goes to Text3
    ld hl,$ff77                     ;loads coordinates into hl
    ld (hl),%00000001               ;what to display @ hl

Equation2GetKey:
    call _getcode                   ;stores key pressed into a
    cp K_F1                         ;compares a with F1 key
    jp z,VAR4                       ;if F1 jump to VAR4
    cp K_F2                         ;compares a with F2 key
    jp z,VAR5                       ;if F2 jump to VAR5
    cp K_F3                         ;compares a with F3 key
    jp z,VAR6                       ;if F3 jump to VAR6
    call Text8                      ;goes to Text8
    ld c,2                          ;loads c with 2
    jp GetKey                       ;jumps to GetKey

EQU3:
    call Text1                      ;goes to Text1
    ld hl,STR9                      ;loads hl with string
    call Text2                      ;goes to Text2
    ld hl,STR20                     ;loads hl with string
    call Text3                      ;goes to Text3
    ld hl,$ff78                     ;loads coordinates into hl
    ld (hl),%00000001               ;what to display @ hl

Equation3GetKey:
    call _getcode                   ;stores key pressed into a
    cp K_F1                         ;compares a with F1 key
    jp z,VAR7                       ;if F1 jump to VAR7
    cp K_F2                         ;compares a with F2 key
    jp z,VAR8                       ;if F2 jump to VAR8
    cp K_F3                         ;compares a with F3 key
    jp z,VAR9                       ;if F3 jump to VAR9
    call Text8                      ;goes to Text8
    ld c,3                          ;loads c with 3
    jp GetKey                       ;jumps to GetKey

EQU4:
    call Text1                      ;goes to Text1
    ld hl,STR10                     ;loads hl with string
    call Text2                      ;goes to Text2
    ld hl,STR21                     ;loads hl with string
    call Text3                      ;goes to Text3
    ld hl,$ff79                     ;loads coordinates into hl
    ld (hl),%00000001               ;what to display @ hl

Equation4GetKey:
    call _getcode                   ;stores key pressed into a
    cp K_F1                         ;compares a with F1 key
    jp z,VAR10                      ;if F1 jump to VAR10
    cp K_F2                         ;compares a with F2 key
    jp z,VAR11                      ;if F2 jump to VAR11
    cp K_F3                         ;compares a with F3 key
    jp z,VAR12                      ;if F3 jump to VAR12
    call Text8                      ;goes to Text8
    ld c,4                          ;loads c with 4
    jp GetKey                       ;jumps to GetKey

EQU5:
    call Text1                      ;goes to Text1
    ld hl,STR11                     ;loads hl with string
    call Text2                      ;goes to Text2
    ld hl,STR22                     ;loads hl with string
    call Text3                      ;goes to Text3
    ld hl,$ff7a                     ;loads coordinates into hl
    ld (hl),%00000001               ;what to display @ hl

Equation5GetKey:
    call _getcode                   ;stores key pressed into a
    cp K_F1                         ;compares a with F1 key
    jp z,VAR13                      ;if F1 jump to VAR13
    cp K_F2                         ;compares a with F2 key
    jp z,VAR14                      ;if F2 jump to VAR14
    cp K_F3                         ;compares a with F3 key
    jp z,VAR15                      ;if F3 jump to VAR15
    call Text8                      ;goes to Text8
    ld c,5                          ;loads c with 5
    jp GetKey                       ;jumps to GetKey

EQU6:
    call Text1                      ;goes to Text1
    ld hl,STR12                     ;loads hl with string
    call Text2                      ;goes to Text2
    ld hl,STR23                     ;loads hl with string
    call Text3                      ;goes to Text3
    ld hl,$ff7b                     ;loads coordinates into hl
    ld (hl),%00000001               ;what to display @ hl

Equation6GetKey:
    call _getcode                   ;stores key pressed into a
    cp K_F1                         ;compares a with F1 key
    jp z,VAR16                      ;if F1 jump to VAR16
    cp K_F2                         ;compares a with F2 key
    jp z,VAR17                      ;if F2 jump to VAR17
    cp K_F3                         ;compares a with F3 key
    jp z,VAR18                      ;if F3 jump to VAR18
    call Text8                      ;goes to Text8
    ld c,6                          ;loads c with 6
    jp GetKey                       ;jumps to GetKey6

EQU7:
    call Text1                      ;goes to Text1
    ld hl,STR13                     ;loads hl with string
    call Text2                      ;goes to Text2
    ld hl,STR24                     ;loads hl with string
    call Text3                      ;goes to Text3
    ld hl,$ff7c                     ;loads coordinates into hl
    ld (hl),%00000001               ;what to display @ hl

Equation7GetKey:
    call _getcode                   ;stores key pressed into a
    cp K_F1                         ;compares a with F1 key
    jp z,VAR19                      ;if F1 jump to VAR19
    cp K_F2                         ;compares a with F2 key
    jp z,VAR20                      ;if F2 jump to VAR20
    cp K_F3                         ;compares a with F3 key
    jp z,VAR21                      ;if F3 jump to VAR21
    call Text8                      ;goes to Text8
    ld c,7                          ;loads c with 7
    jp GetKey                       ;jumps to GetKey

EQU8:
    call Text1                      ;goes to Text1
    ld hl,STR14                     ;loads hl with string
    call Text2                      ;goes to Text2
    ld hl,STR25                     ;loads hl with string
    call Text3                      ;goes to Text3
    ld hl,$ff7d                     ;loads coordinates into hl
    ld (hl),%00000001               ;what to display @ hl

Equation8GetKey:
    call _getcode                   ;stores key pressed into a
    cp K_F1                         ;compares a with F1 key
    jp z,VAR22                      ;if F1 jump to VAR22
    cp K_F2                         ;compares a with F2 key
    jp z,VAR23                      ;if F2 jump to VAR23
    cp K_F3                         ;compares a with F3 key
    jp z,VAR24                      ;if F3 jump to VAR24
    call Text8                      ;goes to Text8
    ld c,8                          ;loads c with 8
    jp GetKey                       ;jumps to GetKey

EQU9:
    call Text1                      ;goes to Text1
    ld hl,STR15                     ;loads hl with string
    call Text2                      ;goes to Text2
    ld hl,STR26                     ;loads hl with string
    call Text3                      ;goes to Text3
    ld hl,$ff7e                     ;loads coordinates into hl
    ld (hl),%00000001               ;what to display @ hl

Equation9GetKey:
    call _getcode                   ;stores key pressed into a
    cp K_F1                         ;compares a with F1 key
    jp z,VAR25                      ;if F1 jump to VAR25
    cp K_F2                         ;compares a with F2 key
    jp z,VAR26                      ;if F2 jump to VAR26
    cp K_F3                         ;compares a with F3 key
    jp z,VAR27                      ;if F3 jump to VAR27
    cp K_F4                         ;compares a with F4 key
    jp z,VAR28                      ;if F4 jump to VAR28
    call Text8                      ;goes to Text8
    ld c,9                          ;loads c with 9
    jp GetKey                       ;jumps to GetKey

VAR1:
    call SubVar1                    ;goes to SubVar1
    ld hl,E2                        ;print string
    jp SubVar6                      ;jumps to SubVar6

VAR2:
    call SubVar3                    ;goes to SubVar3
    ld hl,E3                        ;print string
    call SubVar11c                  ;goes to SubVar11c
    ld hl,E2                        ;print string
    jp Text7                        ;jumps to Text7

VAR3:
    call SubVar3                    ;goes to SubVar3
    ld hl,E2                        ;print string
    call SubVar5                    ;goes to SubVar5
    ld hl,E3                        ;print string
    jp Text7                        ;jumps to Text7

VAR4:
    call SubVar1                    ;goes to SubVar1
    ld hl,E4                        ;print string
    jp SubVar7                      ;jumps to SubVar7

VAR5:
    call SubVar4                    ;goes to SubVar4
    ld hl,E3                        ;print string
    call SubVar11c                  ;goes to SubVar11c
    ld hl,E4                        ;print string
    jp Text7                        ;jumps to Text7

VAR6:
    call SubVar4                    ;goes to SubVar4
    ld hl,E4                        ;print string
    call SubVar5                    ;goes to SubVar5
    ld hl,E3                        ;print string
    jp Text7                        ;jumps to Text7

VAR7:
    call Text4                      ;goes to Text4
    ld hl,E4                        ;print string
    call SubVar12                   ;goes to SubVar12
    ld hl,E2                        ;print string
    call Input                      ;goes to Input
    call _FPDIV                     ;OP1(Opp) / OP2(Adj) ==> OP1
    call _ATAN                      ;tangent invers of OP1(Opp / Adj) ==> OP1
    jp SubVar7a                     ;jumps to SubVar7a

VAR8:
    call SubVar2                    ;goes to SubVar2
    call _TAN                       ;tan OP1(theta) ==> OP1
    rst 08h                         ;OP1(tan theta) is moved to OP2
    ld hl,E4                        ;print string
    call SubVar11c                  ;goes to SubVar11c
    ld hl,E2                        ;print string
    jp Text7                        ;jumps to Text7

VAR9:
    call SubVar2                    ;goes to SubVar2
    call _TAN                       ;tan OP1(theta) ==> OP1
    rst 08h                         ;OP1(tan theta) is moved to OP2
    ld hl,E2                        ;print string
    call SubVar5                    ;goes to SubVar5
    ld hl,E4                        ;print string
    jp Text7                        ;jumps to Text7

VAR10:
    call SubVar10a                  ;goes to SubVar10a
    ld hl,E7                        ;print string
    call SubVar9a                   ;goes to SubVar9a
    ld hl,E5                        ;print string
    jp Text7                        ;jumps to Text7

VAR11:
    call Text4                      ;goes to Text4
    ld hl,E5                        ;print string
    call SubVar10b                  ;goes to SubVar10b
    ld hl,E7                        ;print string
    call SubVar9a                   ;goes to SubVar9a
    ld hl,E6                        ;print string
    jp Text7                        ;jumps to Text7

VAR12:
    call SubVar10a                  ;goes to SubVar10a
    ld hl,E5                        ;print string
    call Input                      ;goes to Input
    call _FPSQUARE                  ;OP1(A) ^ 2 ==> OP1
    call _op4toop2                  ;OP4( B^2) is moved to OP2
    rst 30h                         ;OP1(A^2) + OP2(B^2) ==> OP1
    call SubVar9b                   ;goes to SubVar9b
    ld hl,E7                        ;print string
    jp Text7                        ;jumps to Text7

VAR13:
    call SubVar3                    ;goes to SubVar3
    call SubVar11b                  ;goes to SubVar11b
    ld hl,E8                        ;print string
    jp Text7                        ;jumps to Text7

VAR14:
    call SubVar3                    ;goes to SubVar3
    ld hl,E8                        ;print string
    call SubVar5                    ;goes to SubVar5
    ld hl,E9                        ;print string
    jp Text7                        ;jumps to Text7

VAR15:
    call Text4                      ;goes to Text4
    ld hl,E9                        ;print string
    call SubVar12                   ;goes to SubVar12
    ld hl,E8                        ;print string
    jp SubVar6                      ;jumps to SubVar6

VAR16:
    call SubVar4                    ;goes to SubVar4
    call SubVar11b                  ;goes to SubVar11b
    ld hl,E10                       ;print string
    jp Text7                        ;jumps to Text7

VAR17:
    call SubVar4                    ;goes to SubVar4
    ld hl,E10                       ;print string
    call SubVar5                    ;goes to SubVar5
    ld hl,E9                        ;print string
    jp Text7                        ;jumps to Text7

VAR18:
    call Text4                      ;goes to Text4
    ld hl,E9                        ;print string
    call SubVar12                   ;goes to SubVar12
    ld hl,E10                       ;print string
    jp SubVar7                      ;jumps to SubVar7

VAR19:
    call SubVar3                    ;goes to SubVar3
    call SubVar11a                  ;goes to SubVar11a
    ld hl,E11                       ;print string
    jp Text7                        ;jumps to Text7

VAR20:
    call SubVar3                    ;goes to SubVar3
    ld hl,E11                       ;print string
    call SubVar5                    ;goes to SubVar5
    ld hl,E12                       ;print string
    jp Text7                        ;jumps to Text7

VAR21:
    call Text4                      ;goes to Text4
    ld hl,E12                       ;print string
    call SubVar12                   ;goes to SubVar12
    ld hl,E11                       ;print string
    jp SubVar6                      ;jumps to SubVar6

VAR22:
    call SubVar4                    ;goes to SubVar4
    call SubVar11a                  ;goes to SubVar11a
    ld hl,E13                       ;print string
    jp Text7                        ;jumps to Text7

VAR23:
    call SubVar4                    ;goes to SubVar4
    ld hl,E13                       ;print string
    call SubVar5                    ;goes to SubVar5
    ld hl,E12                       ;print string
    jp Text7                        ;jumps to Text7

VAR24:
    call Text4                      ;goes to Text4
    ld hl,E12                       ;print string
    call SubVar12                   ;goes to SubVar12
    ld hl,E13                       ;print string
    jp SubVar7                      ;jumps to SubVar7

VAR25:
    call SubVar3                    ;goes to SubVar3
    call SubVar11a                  ;goes to SubVar11a
    call _op1toop4                  ;OP1(W * sin theta) is moved to OP4
    ld hl,E14                       ;print string
    call SubVar8                    ;goes to SubVar8
    ld hl,E5                        ;print stringg
    jp Text7                        ;jumps to Text7

VAR26:
    call SubVar3                    ;goes to SubVar3
    call _op1toop4                  ;OP1(sin theta) is moved to OP4
    ld hl,E5                        ;print string
    call SubVar12                   ;goes to SubVar12
    ld hl,E14                       ;print string
    call SubVar11c                  ;goes to SubVar11c
    call _op4toop2                  ;OP4(sin theta) is moved to OP2
    call _FPDIV                     ;OP1(M * A) / OP2(sin theta) ==> OP1
    ld hl,E12                       ;print string
    jp Text7                        ;jumps to Text7

VAR27:
    call Text4                      ;goes to Text4
    ld hl,E5                        ;print string
    call SubVar12                   ;goes to SubVar12
    ld hl,E14                       ;print string
    call SubVar11c                  ;goes to SubVar11c
    call _op1toop4                  ;op1 is moved to OP4
    ld hl,E12                       ;print string
    call SubVar8                    ;goes to SubVar8
    call _ASIN                      ;sin inverse of OP1((M * A) / W) ==> OP1
    jp SubVar7b                     ;jumps to SubVar7b

VAR28:
    call SubVar3                    ;goes to SubVar3
    call SubVar11a                  ;goes to SubVar11a
    call _op1toop4                  ;OP1(W * sin theta) is moved to OP4
    ld hl,E5                        ;print string
    call SubVar8                    ;goes to SubVar8
    ld hl,E14                       ;print string
    jp Text7                        ;jumps to Text7

SubVar1:
    call Text4                      ;goes to Text4
    ld hl,E3                        ;print string
    call SubVar12                   ;goes to SubVar12
    ret                             ;return

SubVar2:
    call Text4                      ;goes to Text4
    ld hl,E1                        ;print string
    call Input                      ;goes to Input
    ret                             ;return

SubVar3:
    call SubVar2                    ;goes to SubVar2
    call _SIN                       ;sine OP1 ==> OP1
    rst 08h                         ;OP1 is moved to OP2
    ret                             ;return

SubVar4:
    call SubVar2                    ;goes to SubVar2
    call _COS                       ;cosine OP1 ==> OP1
    rst 08h                         ;OP1 is moved to OP2
    ret                             ;return

SubVar5:
    call Input                      ;goes to Input
    call _FPDIV                     ;OP1 / OP2 ==> OP1
    ret                             ;return

SubVar6:
    call Input                      ;goes to Input
    call _FPDIV                     ;OP1 / OP2 ==> OP1
    call _ASIN                      ;inverse sine of OP1 ==> OP1
    ld hl,E1                        ;print string
    jp Text7                        ;jumps to Text7

SubVar7:
    call Input                      ;goes to Input
    call _FPDIV                     ;OP1 / OP2 ==> OP1
    call _ACOS                      ;inverse cosine of OP1 ==> OP1
SubVar7a:
SubVar7b:
    ld hl,E1                        ;print string
    jp Text7                        ;jumps to Text7

SubVar8:
    call SubVar12                   ;goes to SubVar12
    call _op4toop1                  ;OP4 is moved to OP1
    call _FPDIV                     ;OP1 / OP2 ==> OP1
    ret                             ;return

SubVar9a:
    call Input                      ;goes to Input
    call _FPSQUARE                  ;OP1 ^ 2 ==> OP1
    call _op4toop2                  ;OP4 is moved to OP2
    call _FPSUB                     ;OP1 - OP2 ==> OP1
SubVar9b:
    call _SQROOT                    ;square root of OP1 ==> OP1
    ret                             ;return

SubVar10a:
    call Text4                      ;goes to Text4
    ld hl,E6                        ;print string
SubVar10b:
    call Input                      ;goes to Input
    call _FPSQUARE                  ;OP1 ^ 2 ==> OP1
    call _op1toop4                  ;OP1 is moved to OP4
    ret                             ;return

SubVar11a:
    ld hl,E12                       ;print string
    jr SubVar11c                    ;relative jump to SubVar11c
SubVar11b:
    ld hl,E9                        ;print string
SubVar11c:
    call Input                      ;goes to Input
    rst 28h                         ;OP1 * OP2 ==> OP1
    ret                             ;return

SubVar12:
    call Input                      ;goes to Input
    rst 08h                         ;variable is stored to OP2
    ret                             ;return

Text1:
    call _clrScrn                   ;clears screen
    set 3,(iy+5)                    ;inverts text to white text on black
    ld hl,(256*1)+0                 ;loads hl with coordinates
    ld (_curRow),hl                 ;loads _curRow with hl
    ret                             ;return

Text2:
    call _puts                      ;prints string
    res 3,(iy+5)                    ;reverts text back to black on white
    ld hl,(256*3)+2                 ;loads coordinates into hl
    ld (_curRow),hl                 ;loads _curRow with hl
    ld hl,STR16                     ;loads hl with string
    call _puts                      ;prints string
    ld hl,(256*0)+5                 ;loads coordinates into hl
    ld (_curRow),hl                 ;loads _curRow with hl
    ret                             ;return

Text3:
    call _puts                      ;prints string
    call DrawScreen                 ;goes to DrawScreen
    ret                             ;return

Text4:
    call _clrScrn                   ;clear screen
    call _homeup                    ;move to upper left
    ret                             ;return

Text7:
    call _puts                      ;prints string
    call DispAnswer                 ;goes to DispAnswer
    call _getkey                    ;waits for a key to be pressed
    jp Equations1                   ;jumps to Equations1

Text8:
    cp K_ALPHA                      ;compares a with Alpha
    jp z,CalcOff                    ;if Alpha jump to CalcOff
    ret                             ;return

Text9:
    ld (hl),%10000000               ;what to display @ hl
    inc hl                          ;icrease hl by 1
    ld (hl),%00000000               ;what to display @ hl
    inc hl                          ;icrease hl by 1
    ld (hl),%00000001               ;what to display @ hl
    ret                             ;return

Text10:
    call Text1                      ;goes to Text1
    ld hl,STR4                      ;loads hl with string
    call _puts                      ;print string
    res 3,(iy+5)                    ;reverts text back to black on white
    ret                             ;return

Input:
    ld de,_ioprompt                 ;$c324 - string storage for display when prompte
    call _mov10b                    ;$427b - move 10 bytes from hl to de
    ld a,$0d                        ;type of input
                                    ;$0d - # value
                                    ;$0c - string
    ld (_asap_ind),a                ;$d623 - tell ti86 what kind to be inputted
    jp _exec_pg3                    ;$5714 - ti86 os input
                                    ;the number inputted is always stored to OP1
    ret                             ;return

DispAnswer:
    ld a,48                         ;loads a with 48
    call _formReal                  ;forms answer to real #
    ld hl,_OP3                      ;loads answer into hl
    call _puts                      ;prints answer
    call _runindicoff               ;turn off run indicator
    ret                             ;return

CalcOff:
    res  3,(iy+8)                   ;lock the ADP
    set  4,(iy+8)                   ;expire ADP
    call $4101                      ;turns off calculator
    ret                             ;return

Exit:
    res trigdeg,(iy+trigflags)      ;change back to radian mode
    call _clrLCD                    ;clears the screen
    call _homeup                    ;moves cursor to upper left
    ret                             ;return that exits the program

STR2:   .db "      Vectors      ",0   
STR3:   .db "By: Morgan Davies    "
        .db "    Matt Bennett",0
STR4:   .db "  Which Equation?  ",0
STR5:   .db "1)  sin =Opp/Hyp    "
        .db "2)  cos =Adj/Hyp    "
        .db "3)  tan =Opp/Adj    "
        .db "4)  A",18,"+B",18,"=C",18,"         "
        .db "5)  Fv=F(sin )",0
STR6:   .db "6)  Fh=F(cos )      "
        .db "7)  F||=W(sin )     "
        .db "8)  Fper=W(cos )    "
        .db "9)  A=W(sin )/M",0
STR7:   .db "   sin =Opp/Hyp   ",0
STR8:   .db "   cos =Adj/Hyp   ",0
STR9:   .db "   tan =Opp/Adj   ",0
STR10:  .db "      A",18,"+B",18,"=C",18,"     ",0
STR11:  .db "    Fv=F(sin )    ",0
STR12:  .db "    Fh=F(cos )    ",0
STR13:  .db "    F||=W(sin )   ",0
STR14:  .db "   Fper=W(cos )   ",0
STR15:  .db "    A=W(sin )/M   ",0
STR16:  .db "Solve For Which      "
        .db "   Variable?",0
STR17:  .db "EQU1",207,"   EQU2",5,"   1    2    3    4    5    6    7    8    9",0
STR18:  .db "   Opp  Hyp",0
STR19:  .db "   Adj  Hyp",0
STR20:  .db "   Opp  Adj",0
STR21:  .db " A   B    C",0
STR22:  .db "Fv   F    ",0
STR23:  .db "Fh   F    ",0
STR24:  .db "F||  W    ",0
STR25:  .db "Fper W    ",0
STR26:  .db " A   W        M",0

E1: .db "",20,"=?",0
E2: .db "Opp=?",0
E3: .db "Hyp=?",0
E4: .db "Adj=?",0
E5: .db "A=?",0
E6: .db "B=?",0
E7: .db "C=?",0
E8: .db "Fv=?",0
E9: .db "F=?",0
E10: .db "Fh=?",0
E11: .db "F||=?",0
E12: .db "W=?",0
E13: .db "Fper=?",0
E14: .db "M=?",0

;=================================
;Verticle Line Routine           =
;by Matt Bennett                 =
;Vars:  b=length                 =
;       c=line (%10000000)       =
;       hl=location in video mem =
;=================================

DrawLineVertical:
    ld de,$10                       ;loads de with $10
LineLoop:
    ld a,(hl)                       ;loads a with contents of video mem @ hl
    or c                            ;turns on the pixels specified by c w/o affecting others
    ld (hl),a                       ;loads a back into video mem
    add hl,de                       ;moves to next line
    djnz LineLoop                   ;repeat until b=0
    ret                             ;return

DrawLineHorizontal:
    ld (hl),%11111111               ;loads video mem @ hl w/ line
    inc hl                          ;moves one to the right
    djnz DrawLineHorizontal         ;repeat until line is drawn
    ret                             ;return
    
DrawScreen:
    ld hl,ULCorner                  ;loads "ULCorner" sprite
    ld de,$0000                     ;loads coordinates into de
    call GridPutSprite              ;display sprite
    ld hl,URCorner                  ;loads "URCorner" sprite
    ld de,$000f                     ;loads coordinates into de
    call GridPutSprite              ;display sprite
    ld hl,$fc80                     ;loads coordinates into hl
    ld b,48                         ;# of times to loop and display c
    ld c,%10000000                  ;what to display @ c
    call DrawLineVertical           ;draws left side line
    ld hl,$fc8f                     ;looads coordinates into hl
    ld b,48                         ;# of times to loop and display c
    ld c,%00000001                  ;what to display @ c
    call DrawLineVertical           ;draws right side line
    ld hl,$ff70                     ;loads coordinates into hl
    ld b,16                         ;# of times to loop and display hl
    call DrawLineHorizontal         ;draws bottom line
    ld hl,STR17                     ;string to print
    ld bc,256*56+2                  ;column 3, row 57
    ld (_penCol),bc                 ;loads c into _penCol
                                    ;  and b into _penRow
    call _vputs                     ;print it and return
    ld de,$0706                     ;loads start coordinates into de
    ld b,9                          ;# of menu boxes to draw

DrawMenuBoxes:
    push de                         ;gets variable de out of way for GPS
    push bc                         ;gets variable bc out of way for GPS
    ld hl,Menu                      ;loads "Menu" sprite
    call GridPutSprite              ;displays sprite
    pop bc                          ;retrieve variable bc
    pop de                          ;retrieve variable de
    inc de                          ;moves coordinates one to the right
    djnz DrawMenuBoxes              ;repeat
    ld hl,Left                      ;loads "Left" sprite
    ld de,$0700                     ;loads coordinates to de
    call GridPutSprite              ;displays sprite
    ld hl,$fff1                     ;loads coordinates to hl
    ld (hl),%11111111               ;what to display @ hl
    ld hl,Right                     ;loads "Right" sprite
    ld de,$0702                     ;loads coordinates to de
    call GridPutSprite              ;displays sprite
    ld hl,Left                      ;loads "Left" sprite
    ld de,$0703                     ;loads coordinates to de
    call GridPutSprite              ;displays sprite
    ld hl,$fff4                     ;loads coordinates to hl
    ld (hl),%11111111               ;what to display @ hl
    ld hl,Right                     ;loads "Right" sprite
    ld de,$0705                     ;loads coordinates to de
    call GridPutSprite              ;displays sprite
    ret                             ;return
    
GridPutSprite:
    push hl                         ; push hl to stack
    pop ix                          ; ...and pop it into iy
    srl d                           ; de = (128 * y) + x
    rra                             ; carry flag -< msb of a
    and $80                         ; a is either $00 or %80
    or e                            ; add x offset (remember x <= 15
    ld e,a                          ; de = (128 * y) + (x * 8)
    ld hl,$fc00                     ; hl-> video memory
    add hl,de                       ; hl-> video memory + offset
    ld b,8                          ; initialize loop counter
    ld de,16                        ; screen is 16 bytes wide

GPS_Loop:
    ld a,(ix + 0)                   ; get byte from sprite
    ld c,(hl)                       ; load c w/contents of video mem                    |These two lines are
    or c                            ; turn on pixels in sprite w/o turning off others   |my own additions
    ld (hl),a                       ; put byte on screen
    inc ix                          ; move to next byte in sprite
    add hl,de                       ; move to next line on screen
    djnz GPS_Loop                   ; loop until sprite is drawn
    ret                             ; return

Menu:
    .db %00000001
    .db %00000001
    .db %00000001
    .db %00000001
    .db %00000001
    .db %00000001
    .db %10000010
    .db %01111100

ULCorner:
    .db %00000111
    .db %00011111
    .db %00111111
    .db %01111111
    .db %01111111
    .db %11111111
    .db %11111111
    .db %11111111

URCorner:
    .db %11100000
    .db %11111000
    .db %11111100
    .db %11111110
    .db %11111110
    .db %11111111
    .db %11111111
    .db %11111111

Left:
    .db %10000000
    .db %10000000
    .db %10000000
    .db %10000000
    .db %10000000
    .db %10000000
    .db %01000000
    .db %00111111

Right:
    .db %00000001
    .db %00000001
    .db %00000001
    .db %00000001
    .db %00000001
    .db %00000001
    .db %00000010
    .db %11111100

.end
END